class FileTooLargeError(Exception):
    pass


class InvalidImageExtensionError(Exception):
    pass


class ImageURLNotFoundException(Exception):
    pass


class ImagePathNotFoundException(Exception):
    pass


class ImageExtensionNotFoundException(Exception):
    pass
